# twaddle-dict

This repository provides a set of dictionaries for use with 
[Twaddle](https://github.com/chrishengler/twaddle). 

The intention for Twaddle is that any user should provide their
own dictionaries to suit their own purposes, but these are provided
as a demonstration for anybody who wishes to play around with the
package and as a starting point to build from.

Most of these dictionaries draw heavily from 
[a fork of the Rantionary](https://github.com/willwybrow/Rantionary).

They are provided under the MIT license, under which they may be used
by anybody for any purpose.

Pull requests are welcome, whether extending vocabulary or adding new
dictionaries, or improving categorisation of existing vocabulary. 